@@ -108,9 +108,21 @@ class CreateCluster(Command):
          'schema': argumentschema.HBASE_RESTORE_FROM_BACKUP_SCHEMA,
          'help_text': helptext.RESTORE_FROM_HBASE},
         {'name': 'security-configuration',
-         'help_text': helptext.SECURITY_CONFIG}
+         'help_text': helptext.SECURITY_CONFIG},
+        {'name': 'custom-ami-id',
+         'help_text' : helptext.CUSTOM_AMI_ID},
+        {'name': 'ebs-root-volume-size',
+         'help_text' : helptext.EBS_ROOT_VOLUME_SIZE},
+        {'name': 'repo-upgrade-on-boot',
+         'help_text' : helptext.REPO_UPGRADE_ON_BOOT},
+        {'name': 'kerberos-attributes',
+         'schema': argumentschema.KERBEROS_ATTRIBUTES_SCHEMA,
+         'help_text': helptext.KERBEROS_ATTRIBUTES},
+        {'name': 'step-concurrency-level',
+         'cli_type_name': 'integer',
+         'help_text': helptext.STEP_CONCURRENCY_LEVEL}
     ]
-    SYNOPSIS = BasicCommand.FROM_FILE('emr', 'create-cluster-synopsis.rst')
+    SYNOPSIS = BasicCommand.FROM_FILE('emr', 'create-cluster-synopsis.txt')
     EXAMPLES = BasicCommand.FROM_FILE('emr', 'create-cluster-examples.rst')
 
     def _run_main_command(self, parsed_args, parsed_globals):
@@ -303,6 +315,27 @@ class CreateCluster(Command):
             emrutils.apply_dict(
                 params, 'SecurityConfiguration', parsed_args.security_configuration)
 
+        if parsed_args.custom_ami_id is not None:
+            emrutils.apply_dict(
+                params, 'CustomAmiId', parsed_args.custom_ami_id
+            )
+        if parsed_args.ebs_root_volume_size is not None:
+            emrutils.apply_dict(
+                params, 'EbsRootVolumeSize', int(parsed_args.ebs_root_volume_size)
+            )
+
+        if parsed_args.repo_upgrade_on_boot is not None:
+            emrutils.apply_dict(
+                params, 'RepoUpgradeOnBoot', parsed_args.repo_upgrade_on_boot
+            )
+
+        if parsed_args.kerberos_attributes is not None:
+            emrutils.apply_dict(
+                params, 'KerberosAttributes', parsed_args.kerberos_attributes)
+
+        if parsed_args.step_concurrency_level is not None:
+            params['StepConcurrencyLevel'] = parsed_args.step_concurrency_level
+
         self._validate_required_applications(parsed_args)
 
         run_job_flow_response = emrutils.call(
@@ -317,11 +350,14 @@ class CreateCluster(Command):
 
     def _construct_result(self, run_job_flow_result):
         jobFlowId = None
+        clusterArn = None
         if run_job_flow_result is not None:
             jobFlowId = run_job_flow_result.get('JobFlowId')
+            clusterArn = run_job_flow_result.get('ClusterArn')
 
         if jobFlowId is not None:
-            return {'ClusterId': jobFlowId}
+            return {'ClusterId': jobFlowId,
+                    'ClusterArn': clusterArn }
         else:
             return {}
 
@@ -509,8 +545,8 @@ class CreateCluster(Command):
                                                 parsed_args, parsed_configs):
         if parsed_args.use_default_roles:
             configurations = [x for x in configurations
-                              if x.name is not 'service_role' and
-                              x.name is not 'instance_profile']
+                              if x.name != 'service_role' and
+                              x.name != 'instance_profile']
         return configurations
 
     def _handle_emrfs_parameters(self, cluster, emrfs_args, release_label):
